@@ -35,6 +35,121 @@ SEXP rgeos_unaryunion(SEXP env, SEXP obj, SEXP id, SEXP byid ) {
 }
 #endif
 
+#ifdef HAVE_MINIMUMROTATEDRECTANGLE
+SEXP rgeos_minimumrotatedrectangle(SEXP env, SEXP obj, SEXP id, SEXP byid) {
+    return( rgeos_topologyfunc(env, obj, id, byid, &GEOSMinimumRotatedRectangle_r) );
+}
+#endif
+
+#ifdef HAVE_MAKEVALID
+SEXP rgeos_makevalid(SEXP env, SEXP obj, SEXP id, SEXP byid ) {
+    return( rgeos_topologyfunc(env, obj, id, byid, &GEOSMakeValid_r) ); 
+}
+#endif
+
+#ifdef HAVE_MAKEVALIDPARAMS
+SEXP rgeos_makevalidparams(SEXP env, SEXP obj, SEXP id, SEXP byid ) {
+
+    SEXP original, keepCollapsed;
+    original = getAttrib(byid, install("original"));
+    keepCollapsed = getAttrib(byid, install("keepCollapsed"));
+
+    GEOSContextHandle_t GEOShandle = getContextHandle(env);
+
+    SEXP p4s = GET_SLOT(obj, install("proj4string"));
+    GEOSGeom geom = rgeos_convert_R2geos(env, obj);
+    int type = GEOSGeomTypeId_r(GEOShandle, geom);
+    
+    int n = 1;
+    if (LOGICAL_POINTER(byid)[0] && type == GEOS_GEOMETRYCOLLECTION)
+        n = GEOSGetNumGeometries_r(GEOShandle, geom);
+    
+    if (n < 1) error("rgeos_makevalidparams: invalid number of geometries");
+
+    GEOSMakeValidParams *p = GEOSMakeValidParams_create_r(GEOShandle);
+
+    if (LOGICAL_POINTER(original)[0]) {
+        GEOSMakeValidParams_setMethod_r(GEOShandle, p,
+            GEOS_MAKE_VALID_LINEWORK);
+    } else {
+        GEOSMakeValidParams_setMethod_r(GEOShandle, p,
+            GEOS_MAKE_VALID_STRUCTURE);
+    }
+    GEOSMakeValidParams_setKeepCollapsed_r(GEOShandle, p,
+        (int) LOGICAL_POINTER(keepCollapsed)[0]);
+    
+    GEOSGeom *resgeoms = (GEOSGeom *) R_alloc((size_t) n, sizeof(GEOSGeom));
+    
+    for(int i=0; i<n; i++) {
+        const GEOSGeometry *curgeom = (n > 1) ? 
+            (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom, i) : geom;
+        
+        if (curgeom == NULL) 
+            error("rgeos_makevalidparams: unable to get subgeometries");
+
+        resgeoms[i] = GEOSMakeValidWithParams_r(GEOShandle, curgeom, p);
+        
+        if (resgeoms[i] == NULL) {
+            GEOSGeom_destroy_r(GEOShandle, geom);
+            GEOSMakeValidParams_destroy_r(GEOShandle, p);
+            char* errbuf = get_errbuf();
+            error(errbuf);
+        }
+    }
+    
+    GEOSGeom_destroy_r(GEOShandle, geom);
+    GEOSMakeValidParams_destroy_r(GEOShandle, p);
+    
+    GEOSGeom res = (n == 1) ? resgeoms[0]
+                    : GEOSGeom_createCollection_r(GEOShandle, GEOS_GEOMETRYCOLLECTION, resgeoms, (unsigned int) n);
+    
+    return( rgeos_convert_geos2R(env, res, p4s, id) ); // releases res
+}
+#endif
+
+#ifdef HAVE_MAXIMUMINSSCRIBEDCIRCLE
+SEXP rgeos_maximuminscribedcircle(SEXP env, SEXP obj, SEXP id, SEXP byid, SEXP tol) {
+    
+    GEOSContextHandle_t GEOShandle = getContextHandle(env);
+
+    SEXP p4s = GET_SLOT(obj, install("proj4string"));
+    GEOSGeom geom = rgeos_convert_R2geos(env, obj);
+    int type = GEOSGeomTypeId_r(GEOShandle, geom);
+    
+    int n = 1;
+    if (LOGICAL_POINTER(byid)[0] && type == GEOS_GEOMETRYCOLLECTION)
+        n = GEOSGetNumGeometries_r(GEOShandle, geom);
+    
+    if (n < 1) error("rgeos_maximuminscribedcircle: invalid number of geometries");
+    
+    GEOSGeom *resgeoms = (GEOSGeom *) R_alloc((size_t) n, sizeof(GEOSGeom));
+    
+    for(int i=0; i<n; i++) {
+        const GEOSGeometry *curgeom = (n > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom, i)
+                                       : geom;
+        
+        if (curgeom == NULL) 
+            error("rgeos_maximuminscribedcircle: unable to get subgeometries");
+        
+        resgeoms[i] = GEOSMaximumInscribedCircle_r(GEOShandle, curgeom,
+            NUMERIC_POINTER(tol)[0]);
+        if (resgeoms[i] == NULL) {
+            GEOSGeom_destroy_r(GEOShandle, geom);
+            char* errbuf = get_errbuf();
+            error(errbuf);
+        }
+    }
+    
+    GEOSGeom_destroy_r(GEOShandle, geom);
+    
+    GEOSGeom res = (n == 1) ? resgeoms[0]
+                    : GEOSGeom_createCollection_r(GEOShandle, GEOS_GEOMETRYCOLLECTION, resgeoms, (unsigned int) n);
+    
+    return( rgeos_convert_geos2R(env, res, p4s, id) ); // releases res
+}
+#endif
+
+
 #ifdef HAVE_DELAUNAY
 SEXP rgeos_delaunaytriangulation(SEXP env, SEXP obj, SEXP tol,
   SEXP onlyEdges) {
@@ -80,12 +195,6 @@ SEXP rgeos_delaunaytriangulation(SEXP env, SEXP obj, SEXP tol,
 }
 #endif
 
-#ifdef HAVE_MAKEVALID
-SEXP rgeos_makevalid(SEXP env, SEXP obj, SEXP id, SEXP byid ) {
-    return( rgeos_topologyfunc(env, obj, id, byid, &GEOSMakeValid_r) ); 
-}
-#endif
-
 
 #ifdef HAVE_COVERAGEUNION
 SEXP rgeos_coverageunion(SEXP env, SEXP obj, SEXP id, SEXP byid ) {
